summaryrefslogtreecommitdiff
path: root/gcc/tree-ssa-sink.c
diff options
context:
space:
mode:
authordnovillo <dnovillo@138bc75d-0d04-0410-961f-82ee72b054a4>2006-03-01 22:35:42 +0000
committerdnovillo <dnovillo@138bc75d-0d04-0410-961f-82ee72b054a4>2006-03-01 22:35:42 +0000
commiteff665b74f08f74b4d910a3797bcc4fb6c255691 (patch)
tree01a72a7a29f8e1046cda441db6c683b0feeb510d /gcc/tree-ssa-sink.c
parent0b5dc8b53229dd77c976c58b483364efd9228845 (diff)
downloadgcc-eff665b74f08f74b4d910a3797bcc4fb6c255691.tar.gz
* tree.def (SYMBOL_MEMORY_TAG): Rename from TYPE_MEMORY_TAG.
Update all users. * tree-pass.h (PROP_smt_usage): Rename from PROP_tmt_usage. Update all users. (TODO_update_smt_usage): Rename from TODO_update_tmt_usage. Update all users. * tree.h (SMT_USED_ALONE): Rename from TMT_USED_ALONE. Update all users. * tree-flow.h (struct var_ann_d): Rename field 'type_mem_tag' to 'symbol_mem_tag'. Update all users. * doc/tree-ssa.texi: Update documentation to reflect TMT->SMT rename. git-svn-id: svn+ssh://gcc.gnu.org/svn/gcc/trunk@111617 138bc75d-0d04-0410-961f-82ee72b054a4
Diffstat (limited to 'gcc/tree-ssa-sink.c')
-rw-r--r--gcc/tree-ssa-sink.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/gcc/tree-ssa-sink.c b/gcc/tree-ssa-sink.c
index 3242f3f4533..7e4e14291ac 100644
--- a/gcc/tree-ssa-sink.c
+++ b/gcc/tree-ssa-sink.c
@@ -168,7 +168,7 @@ is_hidden_global_store (tree stmt)
variable.
Therefore, we check the base address of the LHS. If the
- address is a pointer, we check if its name tag or type tag is
+ address is a pointer, we check if its name tag or symbol tag is
a global variable. Otherwise, we check if the base variable
is a global. */
lhs = TREE_OPERAND (stmt, 0);
@@ -194,12 +194,12 @@ is_hidden_global_store (tree stmt)
tree ptr = TREE_OPERAND (lhs, 0);
struct ptr_info_def *pi = SSA_NAME_PTR_INFO (ptr);
tree nmt = (pi) ? pi->name_mem_tag : NULL_TREE;
- tree tmt = var_ann (SSA_NAME_VAR (ptr))->type_mem_tag;
+ tree smt = var_ann (SSA_NAME_VAR (ptr))->symbol_mem_tag;
- /* If either the name tag or the type tag for PTR is a
+ /* If either the name tag or the symbol tag for PTR is a
global variable, then the store is necessary. */
if ((nmt && is_global_var (nmt))
- || (tmt && is_global_var (tmt)))
+ || (smt && is_global_var (smt)))
{
return true;
}